==> kubernetes-model-core-6.4.1-sources.jar: io/fabric8/kubernetes/api/model/GenericKubernetesResourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import java.lang.Deprecated;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.Object;
import java.lang.String;
import java.lang.Boolean;
import java.util.Map;
import java.util.LinkedHashMap;

 /**
  * Generated
  */
public interface GenericKubernetesResourceFluent<A extends GenericKubernetesResourceFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public GenericKubernetesResourceFluent.MetadataNested<A> withNewMetadata();
  public GenericKubernetesResourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public GenericKubernetesResourceFluent.MetadataNested<A> editMetadata();
  public GenericKubernetesResourceFluent.MetadataNested<A> editOrNewMetadata();
  public GenericKubernetesResourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<GenericKubernetesResourceFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}

==> kubernetes-model-core-6.7.1-sources.jar: io/fabric8/kubernetes/api/model/GenericKubernetesResourceFluent.java <==
package io.fabric8.kubernetes.api.model;

import com.fasterxml.jackson.annotation.JsonIgnore;
import com.fasterxml.jackson.annotation.JsonProperty;
import io.fabric8.kubernetes.api.builder.Fluent;
import io.fabric8.kubernetes.api.builder.Nested;
import java.lang.String;
import java.util.LinkedHashMap;
import java.lang.Deprecated;
import java.lang.Object;
import java.lang.Boolean;
import java.util.Map;

 /**
  * Generated
  */
public interface GenericKubernetesResourceFluent<A extends GenericKubernetesResourceFluent<A>> extends Fluent<A>{
  public String getApiVersion();
  public A withApiVersion(String apiVersion);
  public Boolean hasApiVersion();
  public String getKind();
  public A withKind(String kind);
  public Boolean hasKind();
  
  /**
   * This method has been deprecated, please use method buildMetadata instead.
   * @return The buildable object.
   */
  @Deprecated
  public ObjectMeta getMetadata();
  public ObjectMeta buildMetadata();
  public A withMetadata(ObjectMeta metadata);
  public Boolean hasMetadata();
  public GenericKubernetesResourceFluent.MetadataNested<A> withNewMetadata();
  public GenericKubernetesResourceFluent.MetadataNested<A> withNewMetadataLike(ObjectMeta item);
  public GenericKubernetesResourceFluent.MetadataNested<A> editMetadata();
  public GenericKubernetesResourceFluent.MetadataNested<A> editOrNewMetadata();
  public GenericKubernetesResourceFluent.MetadataNested<A> editOrNewMetadataLike(ObjectMeta item);
  public A addToAdditionalProperties(String key,Object value);
  public A addToAdditionalProperties(Map<String,Object> map);
  public A removeFromAdditionalProperties(String key);
  public A removeFromAdditionalProperties(Map<String,Object> map);
  public Map<String,Object> getAdditionalProperties();
  public <K,V>A withAdditionalProperties(Map<String,Object> additionalProperties);
  public Boolean hasAdditionalProperties();
  public interface MetadataNested<N> extends Nested<N>,ObjectMetaFluent<GenericKubernetesResourceFluent.MetadataNested<N>>{
    public N and();
    public N endMetadata();
    
  }
  
}
